use eframe::egui::{self, pos2, Color32, Rounding};

pub struct TransferMenuState {
    pub transfer_name: String,
    pub source_region: String,
    pub destination_region: String,
    pub source_row_interleave: f32,
    pub source_column_interleave: f32,
}

impl Default for TransferMenuState {
    fn default() -> Self {
        Self {
            transfer_name: String::default(),
            source_region: String::default(),
            destination_region: String::default(),
            source_row_interleave: 1.0,
            source_column_interleave: 1.0,
        }
    }
}

pub fn transfer_menu(ui: &mut egui::Ui, state: &mut TransferMenuState) {
    ui.horizontal(|ui| {
        ui.add(egui::Label::new("Name"));
        ui.add(
            egui::TextEdit::singleline(&mut state.transfer_name)
                .hint_text("Transfer Name")
                .horizontal_align(egui::Align::Center),
        );
    });

    ui.horizontal(|ui| {
        ui.add(egui::Label::new("Source Region"));
        ui.add(
            egui::TextEdit::singleline(&mut state.source_region)
                .hint_text("Source Region")
                .char_limit(9)
                .horizontal_align(egui::Align::Center),
        );
    });
    ui.end_row();

    ui.horizontal(|ui| {
        ui.add(egui::Label::new("Destination Region"));
        ui.add(
            egui::TextEdit::singleline(&mut state.destination_region)
                .hint_text("Destination Region")
                .char_limit(9)
                .horizontal_align(egui::Align::Center),
        );
    });

    ui.vertical(|ui| {
        ui.label("Source Interleave");
        ui.horizontal(|ui| {
            ui.label("Row: ");
            ui.add(egui::DragValue::new(&mut state.source_row_interleave)
                .fixed_decimals(0)
                .range(0..=30));
            ui.label("Col: ");
            ui.add(egui::DragValue::new(&mut state.source_column_interleave)
                .fixed_decimals(0)
                .range(0..=30));
        });
    });
}
